==> mobile_pos-1.1.1.tar.gz: lib/src/views/terminal/widget/update_terminal_sheet.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/progress_dialog.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class UpdateTerminalInfo extends StatefulWidget {
  final TerminalModel model;
  final Function onUpdated;
  const UpdateTerminalInfo(
      {super.key, required this.model, required this.onUpdated});

  @override
  State<UpdateTerminalInfo> createState() => _UpdateTerminalInfoState();
}

class _UpdateTerminalInfoState extends State<UpdateTerminalInfo> {
  final titleController = TextEditingController();
  @override
  void initState() {
    titleController.text = widget.model.tidLabel ?? "";
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                child: Text(
                  "Edit Terminal Label",
                  style: headling1.copyWith(fontSize: 20),
                ),
              ),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: const RoundedItemContainer(asset: "cancel_icon.png"),
              )
            ],
          ),
          const Gap(4),
          Text("Update your terminal label.",
              style: subtitle2.copyWith(fontSize: 14)),
          const Gap(24),
          RavenPayTextField(
            labelText: "Label Title",
            controller: titleController,
            filledColor:
                pluginTheme.isLightTheme ? const Color(0xffF7F8F7) : null,
          ),
          const Gap(34),
          RavenPayButton(
              buttonText: "Proceed",
              onPressed: () async {
                showDialog(
                    barrierDismissible: false,
                    context: context,
                    builder: (BuildContext context) => const ProgressDialog(
                          status: 'Updating...',
                        ));
                final success = await ApiRequests.updateBankBoxLable(
                    label: titleController.text,
                    serialNumber: widget.model.serial ?? '');

                Navigator.pop(context);
                Navigator.pop(context);
                if (success) {
                  widget.onUpdated();
                  widget.model.tidLabel = titleController.text;
                  showSnack(context, 'Updated successfully');
                } else {
                  showSnack(context, 'Changes failed to save.');
                  return;
                }
              }),
          const Gap(30),
        ],
      ),
    );
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/views/terminal/widget/update_terminal_sheet.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/progress_dialog.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_terminal_details.dart';

class UpdateTerminalInfo extends StatefulWidget {
  final TerminalModel model;
  final Function onUpdated;
  const UpdateTerminalInfo(
      {super.key, required this.model, required this.onUpdated});

  @override
  State<UpdateTerminalInfo> createState() => _UpdateTerminalInfoState();
}

class _UpdateTerminalInfoState extends State<UpdateTerminalInfo> {
  final titleController = TextEditingController();
  @override
  void initState() {
    titleController.text = widget.model.tidLabel ?? "";
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                child: Text(
                  "Edit Terminal Label",
                  style: headling1.copyWith(fontSize: 20),
                ),
              ),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: const RoundedItemContainer(asset: "cancel_icon.png"),
              )
            ],
          ),
          const Gap(4),
          Text("Update your terminal label.",
              style: subtitle2.copyWith(fontSize: 14)),
          const Gap(24),
          RavenPayTextField(
            labelText: "Label Title",
            controller: titleController,
            filledColor:
                pluginTheme.isLightTheme ? const Color(0xffF7F8F7) : null,
          ),
          const Gap(34),
          RavenPayButton(
              buttonText: "Proceed",
              onPressed: () async {
                showDialog(
                    barrierDismissible: false,
                    context: context,
                    builder: (BuildContext context) => const ProgressDialog(
                          status: 'Updating...',
                        ));
                final success = await ApiRequests.updateBankBoxLable(
                    label: titleController.text,
                    serialNumber: widget.model.serial ?? '');

                Navigator.pop(context);
                Navigator.pop(context);
                if (success) {
                  widget.onUpdated();
                  widget.model.tidLabel = titleController.text;
                  showSnack(context, 'Updated successfully');
                } else {
                  showSnack(context, 'Changes failed to save.');
                  return;
                }
              }),
          const Gap(30),
        ],
      ),
    );
  }
}
